summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorDevang Patel <dpatel@apple.com>2009-01-05 19:07:53 +0000
committerDevang Patel <dpatel@apple.com>2009-01-05 19:07:53 +0000
commite520273172b530dbf3beca445d3a7577262b9361 (patch)
tree2f292febeb2233c10da44497e6edcc82ef2309c0 /lib
parent5d5a8975298f037e1b1787ae675cfdc66b766fc3 (diff)
downloadllvm-e520273172b530dbf3beca445d3a7577262b9361.tar.gz
llvm-e520273172b530dbf3beca445d3a7577262b9361.tar.bz2
llvm-e520273172b530dbf3beca445d3a7577262b9361.tar.xz
s/ConstructType/ConstructTypeDIE/g
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@61731 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib')
-rw-r--r--lib/CodeGen/AsmPrinter/DwarfWriter.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/CodeGen/AsmPrinter/DwarfWriter.cpp b/lib/CodeGen/AsmPrinter/DwarfWriter.cpp
index 022ff9a82a..8739c31379 100644
--- a/lib/CodeGen/AsmPrinter/DwarfWriter.cpp
+++ b/lib/CodeGen/AsmPrinter/DwarfWriter.cpp
@@ -1497,9 +1497,9 @@ private:
}
}
- /// ConstructType - Construct basic type die from DIBasicType.
- void ConstructType(CompileUnit *DW_Unit, DIE &Buffer,
- DIBasicType *BTy) {
+ /// ConstructTypeDIE - Construct basic type die from DIBasicType.
+ void ConstructTypeDIE(CompileUnit *DW_Unit, DIE &Buffer,
+ DIBasicType *BTy) {
// Get core information.
const std::string &Name = BTy->getName();
@@ -1512,9 +1512,9 @@ private:
AddUInt(&Buffer, DW_AT_byte_size, 0, Size);
}
- /// ConstructType - Construct derived type die from DIDerivedType.
- void ConstructType(CompileUnit *DW_Unit, DIE &Buffer,
- DIDerivedType *DTy) {
+ /// ConstructTypeDIE - Construct derived type die from DIDerivedType.
+ void ConstructTypeDIE(CompileUnit *DW_Unit, DIE &Buffer,
+ DIDerivedType *DTy) {
// Get core information.
const std::string &Name = DTy->getName();